==> benchmark-api-1.9.3-sources.jar: org/opendaylight/yang/gen/v1/rpcbench/payload/rev150702/RpcbenchRpcRoutesBuilder.java <==
package org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702.rpcbench.rpc.routes.RpcRoute;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link RpcbenchRpcRoutesBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     RpcbenchRpcRoutesBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new RpcbenchRpcRoutesBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of RpcbenchRpcRoutesBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see RpcbenchRpcRoutesBuilder
 * @see Builder
 *
 */
public class RpcbenchRpcRoutesBuilder implements Builder<RpcbenchRpcRoutes> {

    private List<RpcRoute> _rpcRoute;


    Map<Class<? extends Augmentation<RpcbenchRpcRoutes>>, Augmentation<RpcbenchRpcRoutes>> augmentation = Collections.emptyMap();

    public RpcbenchRpcRoutesBuilder() {
    }

    public RpcbenchRpcRoutesBuilder(RpcbenchRpcRoutes base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<RpcbenchRpcRoutes>>, Augmentation<RpcbenchRpcRoutes>> aug =((AugmentationHolder<RpcbenchRpcRoutes>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._rpcRoute = base.getRpcRoute();
    }


    public List<RpcRoute> getRpcRoute() {
        return _rpcRoute;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<RpcbenchRpcRoutes>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    public RpcbenchRpcRoutesBuilder setRpcRoute(final List<RpcRoute> values) {
        this._rpcRoute = values;
        return this;
    }
    
    
    public RpcbenchRpcRoutesBuilder addAugmentation(Class<? extends Augmentation<RpcbenchRpcRoutes>> augmentationType, Augmentation<RpcbenchRpcRoutes> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public RpcbenchRpcRoutesBuilder removeAugmentation(Class<? extends Augmentation<RpcbenchRpcRoutes>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public RpcbenchRpcRoutes build() {
        return new RpcbenchRpcRoutesImpl(this);
    }

    private static final class RpcbenchRpcRoutesImpl
        extends AbstractAugmentable<RpcbenchRpcRoutes>
        implements RpcbenchRpcRoutes {
    
        private final List<RpcRoute> _rpcRoute;
    
        RpcbenchRpcRoutesImpl(RpcbenchRpcRoutesBuilder base) {
            super(base.augmentation);
            this._rpcRoute = base.getRpcRoute();
        }
    
        @Override
        public List<RpcRoute> getRpcRoute() {
            return _rpcRoute;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_rpcRoute);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!RpcbenchRpcRoutes.class.equals(((DataObject)obj).implementedInterface())) {
                return false;
            }
            RpcbenchRpcRoutes other = (RpcbenchRpcRoutes)obj;
            if (!Objects.equals(_rpcRoute, other.getRpcRoute())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                RpcbenchRpcRoutesImpl otherImpl = (RpcbenchRpcRoutesImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<RpcbenchRpcRoutes>>, Augmentation<RpcbenchRpcRoutes>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("RpcbenchRpcRoutes");
            CodeHelpers.appendValue(helper, "_rpcRoute", _rpcRoute);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}

==> benchmark-api-2.0.5-sources.jar: org/opendaylight/yang/gen/v1/rpcbench/payload/rev150702/RpcbenchRpcRoutesBuilder.java <==
package org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702.rpcbench.rpc.routes.RpcRoute;
import org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702.rpcbench.rpc.routes.RpcRouteKey;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link RpcbenchRpcRoutesBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     RpcbenchRpcRoutesBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new RpcbenchRpcRoutesBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of RpcbenchRpcRoutesBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see RpcbenchRpcRoutesBuilder
 * @see Builder
 *
 */
public class RpcbenchRpcRoutesBuilder implements Builder<RpcbenchRpcRoutes> {

    private Map<RpcRouteKey, RpcRoute> _rpcRoute;


    Map<Class<? extends Augmentation<RpcbenchRpcRoutes>>, Augmentation<RpcbenchRpcRoutes>> augmentation = Collections.emptyMap();

    public RpcbenchRpcRoutesBuilder() {
    }

    public RpcbenchRpcRoutesBuilder(RpcbenchRpcRoutes base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<RpcbenchRpcRoutes>>, Augmentation<RpcbenchRpcRoutes>> aug =((AugmentationHolder<RpcbenchRpcRoutes>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._rpcRoute = base.getRpcRoute();
    }


    public Map<RpcRouteKey, RpcRoute> getRpcRoute() {
        return _rpcRoute;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<RpcbenchRpcRoutes>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(Objects.requireNonNull(augmentationType));
    }

    public RpcbenchRpcRoutesBuilder setRpcRoute(final Map<RpcRouteKey, RpcRoute> values) {
        this._rpcRoute = values;
        return this;
    }
    
    /**
      * Utility migration setter.
      *
      * <b>IMPORTANT NOTE</b>: This method does not completely match previous mechanics, as the list is processed as
      *                        during this method's execution. Any future modifications of the list are <b>NOT</b>
      *                        reflected in this builder nor its products.
      *
      * @param values Legacy List of values
      * @return this builder
      * @throws IllegalArgumentException if the list contains entries with the same key
      * @throws NullPointerException if the list contains a null entry
      * @deprecated Use {#link #setRpcRoute(Map)} instead.
      */
    @Deprecated(forRemoval = true)
    public RpcbenchRpcRoutesBuilder setRpcRoute(final List<RpcRoute> values) {
        return setRpcRoute(CodeHelpers.compatMap(values));
    }
    
    /**
      * Add an augmentation to this builder's product.
      *
      * @param augmentation augmentation to be added
      * @return this builder
      * @throws NullPointerException if {@code augmentation} is null
      */
    public RpcbenchRpcRoutesBuilder addAugmentation(Augmentation<RpcbenchRpcRoutes> augmentation) {
        return doAddAugmentation(augmentation.implementedInterface(), augmentation);
    }
    
    /**
      * Add or remove an augmentation to this builder's product.
      *
      * @param augmentationType augmentation type to be added or removed
      * @param augmentationValue augmentation value, null if the augmentation type should be removed
      * @return this builder
      * @deprecated Use either {@link #addAugmentation(Augmentation)} or {@link #removeAugmentation(Class)} instead.
      */
    @Deprecated(forRemoval = true)
    public RpcbenchRpcRoutesBuilder addAugmentation(Class<? extends Augmentation<RpcbenchRpcRoutes>> augmentationType, Augmentation<RpcbenchRpcRoutes> augmentationValue) {
        return augmentationValue == null ? removeAugmentation(augmentationType) : doAddAugmentation(augmentationType, augmentationValue);
    }
    
    /**
      * Remove an augmentation from this builder's product. If this builder does not track such an augmentation
      * type, this method does nothing.
      *
      * @param augmentationType augmentation type to be removed
      * @return this builder
      */
    public RpcbenchRpcRoutesBuilder removeAugmentation(Class<? extends Augmentation<RpcbenchRpcRoutes>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }
    
    private RpcbenchRpcRoutesBuilder doAddAugmentation(Class<? extends Augmentation<RpcbenchRpcRoutes>> augmentationType, Augmentation<RpcbenchRpcRoutes> augmentationValue) {
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }

    @Override
    public RpcbenchRpcRoutes build() {
        return new RpcbenchRpcRoutesImpl(this);
    }

    private static final class RpcbenchRpcRoutesImpl
        extends AbstractAugmentable<RpcbenchRpcRoutes>
        implements RpcbenchRpcRoutes {
    
        private final Map<RpcRouteKey, RpcRoute> _rpcRoute;
    
        RpcbenchRpcRoutesImpl(RpcbenchRpcRoutesBuilder base) {
            super(base.augmentation);
            this._rpcRoute = CodeHelpers.emptyToNull(base.getRpcRoute());
        }
    
        @Override
        public Map<RpcRouteKey, RpcRoute> getRpcRoute() {
            return _rpcRoute;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_rpcRoute);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!RpcbenchRpcRoutes.class.equals(((DataObject)obj).implementedInterface())) {
                return false;
            }
            RpcbenchRpcRoutes other = (RpcbenchRpcRoutes)obj;
            if (!Objects.equals(_rpcRoute, other.getRpcRoute())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                RpcbenchRpcRoutesImpl otherImpl = (RpcbenchRpcRoutesImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<RpcbenchRpcRoutes>>, Augmentation<RpcbenchRpcRoutes>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("RpcbenchRpcRoutes");
            CodeHelpers.appendValue(helper, "_rpcRoute", _rpcRoute);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}
